==> haskell-data-clist-0.2-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-3MhQsuEK1pk3aGftbm1c2N
key:                  data-clist-0.2-3MhQsuEK1pk3aGftbm1c2N
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  d2cbafc7d9fbdfb0b195709b91d4c6a0
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-clist-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-3MhQsuEK1pk3aGftbm1c2N
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.2-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-K9MdgyIUrWe3U5z3YfaSji
key:                  data-clist-0.2-K9MdgyIUrWe3U5z3YfaSji
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  de9c3c831558284c2c2e12d5068e99bc
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-clist-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-K9MdgyIUrWe3U5z3YfaSji
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
